==> zio-aws-macie2_2.12-5.17.129.1-sources.jar: zio/aws/macie2/model/S3BucketOwner.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class S3BucketOwner(
    displayName: Option[__string] = None,
    id: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.S3BucketOwner = {
    import S3BucketOwner.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.S3BucketOwner
      .builder()
      .optionallyWith(
        displayName.map(value => __string.unwrap(value): java.lang.String)
      )(_.displayName)
      .optionallyWith(
        id.map(value => __string.unwrap(value): java.lang.String)
      )(_.id)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.S3BucketOwner.ReadOnly =
    zio.aws.macie2.model.S3BucketOwner.wrap(buildAwsValue())
}
object S3BucketOwner {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.S3BucketOwner
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.S3BucketOwner = zio.aws.macie2.model
      .S3BucketOwner(displayName.map(value => value), id.map(value => value))
    def displayName: Option[__string]
    def id: Option[__string]
    def getDisplayName: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("displayName", displayName)
    def getId: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("id", id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.S3BucketOwner
  ) extends zio.aws.macie2.model.S3BucketOwner.ReadOnly {
    override val displayName: Option[__string] = scala
      .Option(impl.displayName())
      .map(value => zio.aws.macie2.model.primitives.__string(value))
    override val id: Option[__string] = scala
      .Option(impl.id())
      .map(value => zio.aws.macie2.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.S3BucketOwner
  ): zio.aws.macie2.model.S3BucketOwner.ReadOnly = new Wrapper(impl)
}

==> zio-aws-macie2_2.12-5.17.150.1-sources.jar: zio/aws/macie2/model/S3BucketOwner.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class S3BucketOwner(
    displayName: Option[__string] = None,
    id: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.S3BucketOwner = {
    import S3BucketOwner.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.S3BucketOwner
      .builder()
      .optionallyWith(displayName.map(value => value: java.lang.String))(
        _.displayName
      )
      .optionallyWith(id.map(value => value: java.lang.String))(_.id)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.S3BucketOwner.ReadOnly =
    zio.aws.macie2.model.S3BucketOwner.wrap(buildAwsValue())
}
object S3BucketOwner {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.S3BucketOwner
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.S3BucketOwner = zio.aws.macie2.model
      .S3BucketOwner(displayName.map(value => value), id.map(value => value))
    def displayName: Option[__string]
    def id: Option[__string]
    def getDisplayName: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("displayName", displayName)
    def getId: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("id", id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.S3BucketOwner
  ) extends zio.aws.macie2.model.S3BucketOwner.ReadOnly {
    override val displayName: Option[__string] =
      scala.Option(impl.displayName()).map(value => value: __string)
    override val id: Option[__string] =
      scala.Option(impl.id()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.S3BucketOwner
  ): zio.aws.macie2.model.S3BucketOwner.ReadOnly = new Wrapper(impl)
}
